@@ -38,7 +38,7 @@ my %Package;
 
 #  Version information
 #
-$VERSION='2.014';
+$VERSION='2.015';
 
 
 #  Debug load
@@ -287,6 +287,14 @@ sub uri {
 }
 
 
+sub document_root {
+
+    my $r=shift();
+    @_ ? $r->{'document_root'}=shift() : $r->{'document_root'} || $ENV{'DOCUMENT_ROOT'}
+    
+}
+
+
 sub output_filters {
 
     #  Stub
@@ -371,7 +379,6 @@ sub args {
 }
 
 
-
 sub AUTOLOAD {
 
     my ($r, $v)=@_;
